# Source Code
## Author: Rohan Singh (and possibly more people)

This directory contains the source code of the SNUPy project. The source code is further divided into other subdirectories.  

## Datasets
This directory contains the source code to provide datasets that the API users can utilize. These datasets can be used to try out our Neural Networks or in other side projects without using external downloads.  

The datasetsare fairly standard and each dataset will be returned in different formats:  
  - **Pandas Dataframes**  
  - **Python Lists**  
  - **Numpy NDArrays**   

## Neural Networks
This directory contains the source code for various types of Neural Networks. The Neural Networks are very lightweight and flexible, which makes them very fast and customizable based on the needs of the user. 


## Forking 
Please feel free to fork this repository to add more source code into this directory. I will try to look at all pull requests as soon as possible.  


